Function wpilib_sys::bindings::HAL_CheckAnalogInputChannel
source · Expand description
Checks that the analog output channel number is value. Verifies that the analog channel number is one of the legal channel numbers. Channel numbers are 0-based.
@param channel The analog output channel number. @return Analog channel is valid