pub unsafe extern "C" fn HAL_CheckAnalogOutputChannel(
    channel: i32
) -> HAL_Bool
Checks that the analog output channel number is value.

Verifies that the analog channel number is one of the legal channel numbers. Channel numbers are 0-based.

@return Analog channel is valid