Function wpilib_sys::bindings::HAL_CheckPDPChannel
source · Expand description
Checks if a PDP channel is valid.
@param channel the channel to check @return true if the channel is valid, otherwise false
Checks if a PDP channel is valid.
@param channel the channel to check @return true if the channel is valid, otherwise false