Function wpilib_sys::bindings::HAL_CheckRelayChannel
source · Expand description
Checks if a relay channel is valid.
@param channel the channel to check @return true if the channel is valid, otherwise false
Checks if a relay channel is valid.
@param channel the channel to check @return true if the channel is valid, otherwise false