pub unsafe extern "C" fn HAL_GetCompressorClosedLoopControl(
compressorHandle: HAL_CompressorHandle,
status: *mut i32,
) -> HAL_BoolExpand description
Gets if the compressor is in closed loop mode.
@param compressorHandle the compressor handle @return true if the compressor is in closed loop mode, otherwise false