Function wpilib_sys::bindings::HAL_GetSerialBytesReceived
source · Expand description
Gets the number of bytes currently in the read buffer.
@param port the serial port @return the number of bytes in the read buffer