pub unsafe extern "C" fn HAL_InitializeNotifier(
    status: *mut i32
) -> HAL_NotifierHandle
Initializes a notifier.

A notifier is an FPGA controller timer that triggers at requested intervals based on the FPGA time. This can be used to make precise control loops.

@return the created notifier