pub unsafe extern "C" fn HAL_IsNewControlData() -> HAL_Bool
Has a new control packet from the driver station arrived since the last time this function was called?

@return true if the control data has been updated since the last call