HAL_ObserveUserProgramTeleop

Function HAL_ObserveUserProgramTeleop 

pub unsafe extern "C" fn HAL_ObserveUserProgramTeleop()
Sets the teleoperated enabled flag in the DS.

This is used for the DS to ensure the robot is properly responding to its state request. Ensure this get called about every 50ms, or the robot will be disabled by the DS.