pub unsafe extern "C" fn HAL_ResetEncoder(
    encoderHandle: HAL_EncoderHandle,
    status: *mut i32
)
Reads the current encoder value.

Read the value at this instant. It may still be running, so it reflects the current value. Next time it is read, it might have a different value.

@param encoderHandle the encoder handle @return the current encoder value