Function wpilib_sys::bindings::HAL_SetAnalogSampleRate
source · Expand description
Sets the sample rate.
This is a global setting for the Athena and effects all channels.
@param samplesPerSecond The number of samples per channel per second.