Function wpilib_sys::bindings::HAL_SetCounterDownSourceEdge
source · pub unsafe extern "C" fn HAL_SetCounterDownSourceEdge(
counterHandle: HAL_CounterHandle,
risingEdge: HAL_Bool,
fallingEdge: HAL_Bool,
status: *mut i32
)Expand description
Sets the down source to either detect rising edges or falling edges. Note that both are allowed to be set true at the same time without issues.
@param counterHandle the counter handle @param risingEdge true to trigger on rising @param fallingEdge true to trigger on falling