Function wpilib_sys::bindings::HAL_SetCounterPulseLengthMode
source · pub unsafe extern "C" fn HAL_SetCounterPulseLengthMode(
counterHandle: HAL_CounterHandle,
threshold: f64,
status: *mut i32
)Expand description
Configures the counter to count in up or down based on the length of the input pulse.
This mode is most useful for direction sensitive gear tooth sensors.
@param counterHandle the counter handle @param threshold The pulse length beyond which the counter counts the opposite direction (seconds)