Function wpilib_sys::bindings::HAL_SetCounterReverseDirection
source · pub unsafe extern "C" fn HAL_SetCounterReverseDirection(
counterHandle: HAL_CounterHandle,
reverseDirection: HAL_Bool,
status: *mut i32
)Expand description
Sets the Counter to return reversed sensing on the direction.
This allows counters to change the direction they are counting in the case of 1X and 2X quadrature encoding only. Any other counter mode isn’t supported.
@param counterHandle the counter handle @param reverseDirection true if the value counted should be negated.