Function wpilib_sys::bindings::HAL_SetSerialDataBits
source · Expand description
Sets the number of data bits on a serial port.
Defaults to 8.
@param port the serial port @param bits the number of data bits (5-8)
Sets the number of data bits on a serial port.
Defaults to 8.
@param port the serial port @param bits the number of data bits (5-8)