Function wpilib_sys::bindings::HAL_CheckAnalogOutputChannel
source · Expand description
Checks that the analog output channel number is value.
Verifies that the analog channel number is one of the legal channel numbers. Channel numbers are 0-based.
@return Analog channel is valid