Function wpilib_sys::bindings::HAL_InitializeNotifier
source · pub unsafe extern "C" fn HAL_InitializeNotifier(
status: *mut i32
) -> HAL_NotifierHandleExpand description
Initializes a notifier.
A notifier is an FPGA controller timer that triggers at requested intervals based on the FPGA time. This can be used to make precise control loops.
@return the created notifier