Function wpilib_sys::bindings::HAL_IsNewControlData
source · pub unsafe extern "C" fn HAL_IsNewControlData() -> HAL_BoolExpand description
Has a new control packet from the driver station arrived since the last time this function was called?
@return true if the control data has been updated since the last call